Logger class

Structured logger that prefixes each message with timestamp, level, and the caller's file name, function, and line number extracted from the Dart stack trace.

Constructors

Logger()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

d(String message) → void
e(String message) → void
i(String message) → void
v(String message) → void
w(String message) → void